from typing import *

# usage.scipy: 2
Generator: object

# usage.dask: 5
# usage.pandas: 4
# usage.scipy: 9
# usage.skimage: 1
# usage.sklearn: 22
RandomState: object

# usage.dask: 20
# usage.pandas: 15
# usage.scipy: 4
# usage.skimage: 2
# usage.xarray: 2
choice: object

# usage.scipy: 3
dirichlet: object

# usage.scipy: 2
exponential: object

# usage.matplotlib: 1
# usage.scipy: 1
lognormal: object

# usage.dask: 1
multinomial: object

# usage.scipy: 3
multivariate_normal: object

# usage.dask: 11
# usage.matplotlib: 22
# usage.pandas: 6
# usage.scipy: 32
# usage.skimage: 5
# usage.sklearn: 1
normal: object

# usage.scipy: 5
pareto: object

# usage.scipy: 19
# usage.skimage: 18
rand: object

# usage.dask: 70
# usage.matplotlib: 3
# usage.pandas: 84
# usage.scipy: 18
# usage.skimage: 14
# usage.sklearn: 8
# usage.xarray: 2
randint: object

# usage.pandas: 4
# usage.scipy: 20
# usage.skimage: 10
# usage.xarray: 6
randn: object

# usage.dask: 15
# usage.pandas: 11
# usage.scipy: 9
# usage.xarray: 4
random: object

# usage.scipy: 1
random_sample: object

# usage.dask: 1
# usage.matplotlib: 1
# usage.skimage: 4
seed: object

# usage.scipy: 1
standard_cauchy: object

# usage.dask: 1
# usage.matplotlib: 3
# usage.pandas: 2
# usage.scipy: 28
# usage.skimage: 22
# usage.sklearn: 4
# usage.xarray: 1
uniform: object
